# Alternatives

## dotfiles

Keeping your dotfiles in a git repo is a great way to keep track of your configuration.

`check-config`:

- can install packages
- works not just on complete files, but also on snippets
- works both on global files and on per-project/repository files
- supports templating with variables (in toml file or from environment variables)

## [dotbins](https://github.com/basnijholt/dotbins)

dotbins is an greate extension to dotbins to install packages.

`check-config`:

- does support custom install / uninstall commands
- works not just on complete files, but also on snippets, which can be included
  from several locations
